-- Notecase Pro sample script (requires Notecase Pro >= 3.1.3)
--
-- Description:
-- Write all notes (ID, Title) of the currently active document into the selected log file
-- The selected file must be a plain text file, not a NoteCase Pro document.

-- make sure app version supports necessary scriptable program commands
nMaj, nMin, nRev = Nc_Config_GetAppVersion()
if (nMaj < 3 or (nMaj == 3 and nMin < 1) or (nMaj == 3 and nMin == 1 and nRev < 3)) then
	Nc_GUI_MessageBox("ERROR: Script requires NcPro version >= 3.1.3")
	return
end

-- Nc_GUI_FileDlg - Show file selector window
-- PARAMETER 1: 1 - file open dialog, 0 - file save dialog
filename = Nc_GUI_FileDlg(0)

-- check if the output file was selected
if filename:len() == 0 then
	Nc_GUI_MessageBox("No output file selected, aborting")
	return
end

-- open output file
outfile = io.open(filename,"w")

-- get info on the currently active document
nDocID = Nc_Doc_ID_GetCur()
nNoteCount = Nc_Doc_NoteCount(nDocID)

-- for each document note
for i=1,nNoteCount do 
	-- get info on the note (note indexes start from 0)
	strNoteID    = Nc_Note_ID_GetByIdx(nDocID, i-1)
	strNoteTitle = Nc_Note_Title_Get(nDocID, strNoteID)

	-- write note info into the file
	outfile:write("Note ID:" .. strNoteID .. "\n")
	outfile:write("Note title:" .. strNoteTitle .. "\n\n")
end 

-- close output file
outfile:close()