-- Notecase Pro script (requires  Notecase Pro v 3.1.5 or later)
-- Script name: JoinLines.lua
-- Version: 1.0
--
-- Description:
-- Reformats paragraphs that are separated by at least one blank line,
-- removing any single line breaks or multiple consecutive spaces.   
-- 
-- This script's author, Paul E. Merrell, hereby waives all copyright 
-- and related or neighboring rights to this script, pursuant to the
-- Creative Commons CC0 Universal relinquishment of rights found at
-- http://creativecommons.org/publicdomain/zero/1.0/ 

-- make sure app version supports necessary scriptable program commands
nMaj, nMin, nRev = Nc_Config_GetAppVersion()
if (nMaj < 3 or (nMaj == 3 and nMin < 1) or (nMaj == 3 and nMin == 1 and nRev < 5)) then
	Nc_GUI_MessageBox("ERROR: Script requires NoteCasePro version >= 3.1.5")
 return
end

--store IDs of current document and note as variables nDocID and strNoteID
nDocID = Nc_Doc_ID_GetCur()
strNoteID = Nc_Note_ID_GetCur(nDocID)

-- check to see if note is selected and abort the script if not
if strNoteID == "" then
 	Nc_GUI_MessageBox("ERROR: A note must be selected")
 return
end

-- get character offsets for selected text and store as variables
-- nSelFrom and nSelTo
nSelFrom, nSelTo = Nc_Note_SelectionRange_Get(nDocID, strNoteID)

-- abort the script with an error message if no text is selected
-- (when nSelFrom and nSelTo are equal, their values represent the 
-- zero-width cursor's position and no text is selected) 
if nSelFrom == nSelTo then
	Nc_GUI_MessageBox("ERROR: Text must be selected in the Note Pane    \nwhen using this script.")
 return
end

-- get selected content in HTML format and store as variable strSelection
strSelection = Nc_Note_Content_Get(nDocID, strNoteID, 1, nSelFrom, nSelTo)

-- make sure selection does not include a list or list item element
-- and abort script with a message if it does
if string.find(strSelection, "<UL>") ~= nil then 
	Nc_GUI_MessageBox("ERROR: List markup detected.\nSelection cannot include a bullet list.")
 return
end
if string.find(strSelection, "</UL>") ~= nil then
	Nc_GUI_MessageBox("ERROR: List markup detected.\nSelection cannot include a bullet list.")
 return
end
if string.find(strSelection, "<LI>") ~= nil then
	Nc_GUI_MessageBox("ERROR: List markup detected.\nSelection cannot include a bullet list.")
 return
end
if string.find(strSelection, "</LI>") ~= nil then 
	Nc_GUI_MessageBox("ERROR: List markup detected.\nSelection cannot include a bullet list.")
 return
end

-- BEGIN MODIFYING CONTENT
	
-- replace all occurrences of three consecutive hard line breaks
-- trailed by newlines with character token: @~@ so the line 
-- breaks can be restored later
strSelection = string.gsub(strSelection, "<BR>\n<BR>\n<BR>\n", "@~@")
	
-- replace all occurrences of two consecutive hard line breaks
-- trailed by newlines with character token: ~@~ so the line 
-- breaks can be restored later
strSelection = string.gsub(strSelection, "<BR>\n<BR>\n", "~@~")

-- replace all remaining hard line breaks with a space so 
-- paragraphs can be wrapped
strSelection = string.gsub(strSelection, "<BR>", " ")

-- replace all newlines with a space
strSelection = string.gsub(strSelection, "\n", " ") 

-- now remove excess spaces 

-- if they exist, replace triple spaces with a single space 
strSelection = string.gsub(strSelection, "   ", " ")
 
-- if they exist replace double spaces with a single space
strSelection = string.gsub(strSelection, "  ", " ")

-- now restore the hard line breaks separating paragraphs

-- replace token for three consecutive hard line breaks
-- and their trailing newlines
strSelection = string.gsub(strSelection, "@~@", "<BR>\n<BR>\n<BR>\n") 

-- replace token for two consecutive hard line breaks
-- with trailing newlines
strSelection = string.gsub(strSelection, "~@~", "<BR>\n<BR>\n") 

-- replace the selected content in the note 
Nc_Note_Content_Set(nDocID, strNoteID, strSelection, 1, nSelFrom, nSelTo)

-- be certain that nSelTo equals the greater of nSelFrom and nSelTo
if nSelFrom > nSelTo then
	nSelTo = nSelFrom
end

-- remove selection highlighting and set the cursor position 
-- immediately after the inserted content
Nc_Note_SelectionRange_Set(nDocID, strNoteID, nSelTo, nSelTo)
